@@ -3,7 +3,8 @@
 package UR::ModuleBase;
 
 BEGIN {
-    use Class::Autouse;
+    use Class::Autouse_1_99_02;
+    $INC{"Class/Autouse.pm"} = $INC{"Class/Autouse_1_99_02.pm"};
     no strict;
     no warnings;
     *can = $Class::Autouse::ORIGINAL_CAN;
